diff --git a/DaVinciExamples/python/DaVinciExamples/tupling/option_davinci_configFuntuple.py b/DaVinciExamples/python/DaVinciExamples/tupling/option_davinci_configFuntuple.py
index 4a642169124ed5e17ba4e5bd53bc0fd97e45b7ca..026365d6f9c813550c0720537d7b8d8f596eed4d 100644
--- a/DaVinciExamples/python/DaVinciExamples/tupling/option_davinci_configFuntuple.py
+++ b/DaVinciExamples/python/DaVinciExamples/tupling/option_davinci_configFuntuple.py
@@ -45,7 +45,7 @@ variables = {
 
 
 def main():
-    from DaVinci.algorithms import ConfiguredFuntuple
+    from DaVinci.algorithms import configured_FunTuple
 
     config = {
         "location":
@@ -58,6 +58,6 @@ def main():
     }
 
     tools = []
-    algs = ConfiguredFuntuple({"B0Dspi": config})
+    algs = configured_FunTuple({"B0Dspi": config})
 
     return algs, tools
diff --git a/DaVinciExamples/python/DaVinciExamples/tupling/option_davinci_tupling_from_collections.py b/DaVinciExamples/python/DaVinciExamples/tupling/option_davinci_tupling_from_collections.py
index e8bc8216b9884e86b9ddbc6aa863430cb00ed0af..141f55abff4081981d4503056e22ff24d2a9785d 100644
--- a/DaVinciExamples/python/DaVinciExamples/tupling/option_davinci_tupling_from_collections.py
+++ b/DaVinciExamples/python/DaVinciExamples/tupling/option_davinci_tupling_from_collections.py
@@ -17,13 +17,13 @@ from FunTuple import FunctorCollection, functorcollections
 from FunTuple import FunTuple_Particles as Funtuple
 from DaVinci.algorithms import add_filter
 from DaVinci import options
-from DaVinci.truth_matching import ConfiguredMCTruthAndBkgCatAlg
+from DaVinci.truth_matching import configured_MCTruthAndBkgCatAlg
 
 d02kpi_data = make_data_with_FetchDataFromFile(
     "/Event/HLT2/Hlt2CharmD0ToKmPipLine/Particles")
 
 #get configured "MCTruthAndBkgCatAlg" algorithm for HLT2 output
-mctruth = ConfiguredMCTruthAndBkgCatAlg(inputs=d02kpi_data)
+mctruth = configured_MCTruthAndBkgCatAlg(inputs=d02kpi_data)
 
 # use functorcollections to add variables, please expand when there's new collections :)
 collections = [
diff --git a/DaVinciExamples/python/DaVinciExamples/tupling/option_davinci_tupling_from_hlt2.py b/DaVinciExamples/python/DaVinciExamples/tupling/option_davinci_tupling_from_hlt2.py
index 92106e144643acfd907bdf3cb83c2387529a4062..cfb4085e74a8e1286dbab1185df5a5f090bab173 100644
--- a/DaVinciExamples/python/DaVinciExamples/tupling/option_davinci_tupling_from_hlt2.py
+++ b/DaVinciExamples/python/DaVinciExamples/tupling/option_davinci_tupling_from_hlt2.py
@@ -18,7 +18,7 @@ from PyConf.application import make_data_with_FetchDataFromFile
 from DaVinci.reco_objects import make_pvs_for
 from DaVinci.algorithms import add_filter
 from DaVinci import options
-from DaVinci.truth_matching import ConfiguredMCTruthAndBkgCatAlg
+from DaVinci.truth_matching import configured_MCTruthAndBkgCatAlg
 
 fields = {
     "D0": "[D0 -> K- pi+]CC",
@@ -74,7 +74,7 @@ def main():
                            "HLT_PASS('Hlt2CharmD0ToKmPipLineDecision')")
 
     #get configured "MCTruthAndBkgCatAlg" algorithm for HLT2 output
-    mctruth = ConfiguredMCTruthAndBkgCatAlg(inputs=d02kpi_data)
+    mctruth = configured_MCTruthAndBkgCatAlg(inputs=d02kpi_data)
     #Add true ID info to each of the fields (branches)
     trueid_bkgcat_info = {
         "TRUEID":
diff --git a/DaVinciExamples/python/DaVinciExamples/tupling/option_davinci_tupling_from_spruce_mc.py b/DaVinciExamples/python/DaVinciExamples/tupling/option_davinci_tupling_from_spruce_mc.py
index cc22b4640b704659cd766102afec2580618a9500..d03214468a8c38f9ace34cec08c78915b2249aac 100644
--- a/DaVinciExamples/python/DaVinciExamples/tupling/option_davinci_tupling_from_spruce_mc.py
+++ b/DaVinciExamples/python/DaVinciExamples/tupling/option_davinci_tupling_from_spruce_mc.py
@@ -12,7 +12,7 @@ from FunTuple import FunctorCollection
 import Functors as F
 from FunTuple import FunTuple_Particles as Funtuple
 from FunTuple.functorcollections import Kinematics
-from DaVinci.truth_matching import ConfiguredMCTruthAndBkgCatAlg
+from DaVinci.truth_matching import configured_MCTruthAndBkgCatAlg
 from DaVinci.algorithms import add_filter
 from PyConf.application import make_data_with_FetchDataFromFile
 
@@ -41,7 +41,7 @@ def main():
                            "HLT_PASS('Spruce_Test_lineDecision')")
 
     #get configured "MCTruthAndBkgCatAlg" algorithm for HLT2 output
-    mctruth = ConfiguredMCTruthAndBkgCatAlg(
+    mctruth = configured_MCTruthAndBkgCatAlg(
         inputs=B_data, root_in_tes="/Event/Spruce/HLT2")
     #Add trueid info to each of the branches
     trueid_bkgcat_info = {
diff --git a/Phys/DaVinci/python/DaVinci/algorithms.py b/Phys/DaVinci/python/DaVinci/algorithms.py
index e9a48cabfe09680e0a9960b017b7890eabeaf768..74cc9531b181999e1f3406522e132c6339ec1884 100644
--- a/Phys/DaVinci/python/DaVinci/algorithms.py
+++ b/Phys/DaVinci/python/DaVinci/algorithms.py
@@ -305,7 +305,7 @@ def get_hlt_reports(options, source=''):
     return dec_reports
 
 
-def ConfiguredFuntuple(config):
+def configured_FunTuple(config):
     """
     Function for the FunTuple configuration and instantiation of the related HDR filter.
 
diff --git a/Phys/DaVinci/python/DaVinci/truth_matching.py b/Phys/DaVinci/python/DaVinci/truth_matching.py
index e1e7fc354bfb6cf2cd39985c838001ab9af0dfaa..0960056b7ea6faae54dea486102664b1e7c70be3 100644
--- a/Phys/DaVinci/python/DaVinci/truth_matching.py
+++ b/Phys/DaVinci/python/DaVinci/truth_matching.py
@@ -17,7 +17,7 @@ from PyConf.Tools import BackgroundCategory, BackgroundCategoryViaRelations
 from PyConf.Tools import P2MCPFromProtoP
 
 
-def ConfiguredMCTruthAndBkgCatAlg(
+def configured_MCTruthAndBkgCatAlg(
         inputs,
         relations_locs=["Relations/ChargedPP2MCP", "Relations/NeutralPP2MCP"],
         root_in_tes="/Event/HLT2",
diff --git a/Phys/DaVinci/tests/config/test_algorithms.py b/Phys/DaVinci/tests/config/test_algorithms.py
index 4e8f0d3fdcaf5a4c00868b98050ef15b9da599c1..f8fa22833f7491814a0cfec2341d57a19d55124a 100644
--- a/Phys/DaVinci/tests/config/test_algorithms.py
+++ b/Phys/DaVinci/tests/config/test_algorithms.py
@@ -18,7 +18,7 @@ from DaVinci.optionChecker import DVImportError
 from DaVinci.algorithms import (setup_algorithms, define_fsr_writer,
                                 add_filter, apply_filters_and_unpacking,
                                 setup_user_algorithms, unpack_locations,
-                                ConfiguredFuntuple)
+                                configured_FunTuple)
 
 
 def test_import_main_options():
@@ -253,7 +253,7 @@ def test_apply_filters_and_unpack():
 
 def test_configured_funtuple():
     """
     Check if the ConfiguredFuntuple provides a correct instance of FunTuple.
     """
     from FunTuple.functorcollections import Kinematics
     fields = {'B0': "[B0 -> D_s- pi+]CC"}
@@ -270,6 +270,6 @@ def test_configured_funtuple():
         }
     }
 
-    test_dict = ConfiguredFuntuple(config)
+    test_dict = configured_FunTuple(config)
     assert any("FunTupleBase_Particles/Tuple_TestTuple" in alg.fullname
                for alg in test_dict["TestTuple"])
@@ -253,7 +253,7 @@ def test_apply_filters_and_unpack():
 def test_configured_funtuple():
     """
-    Check if the ConfiguredFuntuple provides a correct instance of FunTuple.
+    Check if the configured_FunTuple provides a correct instance of FunTuple.
     """
     from FunTuple.functorcollections import Kinematics